import * as React from 'react';
import { Text, View } from 'react-native';
import { Svg } from 'react-native-svg';
import * as renderer from 'react-test-renderer';
import { Checkbox } from '../Checkbox';
function onChange(_e, isChecked) {
    console.log(isChecked);
}
describe('Checkbox component tests', function () {
    it('Checkbox default', function () {
        var tree = renderer.create(React.createElement(Checkbox, { label: "Default Checkbox", onChange: onChange, defaultChecked: false })).toJSON();
        expect(tree).toMatchSnapshot();
    });
    it('Checkbox no label', function () {
        var tree = renderer.create(React.createElement(Checkbox, { onChange: onChange, defaultChecked: false })).toJSON();
        expect(tree).toMatchSnapshot();
    });
    it('Checkbox all props', function () {
        var tree = renderer
            .create(React.createElement(Checkbox, { label: "All Props Checkbox", onChange: onChange, defaultChecked: true, labelPosition: "before", disabled: true, shape: "circular", size: "large", required: true }))
            .toJSON();
        expect(tree).toMatchSnapshot();
    });
    it('Checkbox all tokens', function () {
        var BoldCheckbox = Checkbox.customize({
            fontFamily: 'Wingdings',
            fontWeight: '900',
            fontSize: 20,
            checkboxBackgroundColor: 'blue',
            checkboxBorderColor: 'red',
            checkboxBorderRadius: 5,
            checkboxBorderWidth: 2,
            checkboxSize: 11,
            checkmarkColor: 'pink',
            checkmarkOpacity: 0.7,
            checkmarkSize: 7,
            backgroundColor: 'purple',
            color: 'yellow',
            spacingLabelAfter: 7,
            spacingLabelBefore: 9,
            borderColor: 'green',
            borderRadius: 4,
            borderWidth: 2,
        });
        var tree = renderer.create(React.createElement(BoldCheckbox, { label: "All Tokens Checkbox", onChange: onChange, defaultChecked: false })).toJSON();
        expect(tree).toMatchSnapshot();
    });
    it('Checkbox composed', function () {
        var ComposedCheckbox = Checkbox.compose({
            slots: {
                root: View,
                checkbox: View,
                checkmark: Svg,
                label: Text,
                required: Text,
            },
        });
        var tree = renderer.create(React.createElement(ComposedCheckbox, { label: "Composed Button with RNText" })).toJSON();
        expect(tree).toMatchSnapshot();
    });
});
//# sourceMappingURL=Checkbox.test.js.map